==> matrix_sdk-0.1.5.tar.gz: lib/src/event/events.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/event.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/store.dart';

/// Events map that will lazily load from the given
/// [store].
class Events {
  final RoomId _roomId;
  final Map<EventId, Event> _memory = Map();

  final Store store;

  Events(this._roomId, {this.store});

  Future<Event> operator [](EventId id) async {
    // If the room is in memory, return that one
    var fromMemory = _memory[id];
    if (fromMemory != null) {
      return fromMemory;
    }

    // Look in the store
    return await store?.getEvent(_roomId, id);
  }

  void operator []=(EventId key, Event value) async {
    _memory[key] = value;

    await store?.addEvent(_roomId, value);
  }

  Stream<Event> all() async* {
    for (var event in _memory.values) {
      yield event;
    }

    // Load all events to memory
    await for (var event in store?.getEvents(_roomId)) {
      bool shouldYield = false;

      // If the event was not already in memory, yield it
      _memory.putIfAbsent(event.id, () {
        shouldYield = true;
        return event;
      });

      if (shouldYield) {
        yield event;
      }
    }
  }

  Stream<MessageEvent> messages() =>
      all().where((event) => event is MessageEvent);

  Stream<MessageEvent> state() => all().where((event) => event is StateEvent);
}

==> matrix_sdk-0.1.8.tar.gz: lib/src/event/events.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/event.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/store.dart';

/// Events map that will lazily load from the given
/// [store].
class Events {
  final RoomId _roomId;
  final Map<EventId, Event> _memory = Map();

  final Store store;

  Events(this._roomId, {this.store});

  Future<Event> operator [](EventId id) async {
    // If the room is in memory, return that one
    var fromMemory = _memory[id];
    if (fromMemory != null) {
      return fromMemory;
    }

    // Look in the store
    return await store?.getEvent(_roomId, id);
  }

  void operator []=(EventId key, Event value) async {
    _memory[key] = value;

    await store?.addEvent(_roomId, value);
  }

  Stream<Event> all() async* {
    for (var event in _memory.values) {
      yield event;
    }

    // Load all events to memory
    await for (var event in store?.getEvents(_roomId)) {
      bool shouldYield = false;

      // If the event was not already in memory, yield it
      _memory.putIfAbsent(event.id, () {
        shouldYield = true;
        return event;
      });

      if (shouldYield) {
        yield event;
      }
    }
  }

  Stream<MessageEvent> messages() =>
      all().where((event) => event is MessageEvent).cast();

  Stream<MessageEvent> state() =>
      all().where((event) => event is StateEvent).cast();
}
